@@ -95,7 +95,7 @@ class Defog:
             raise Exception("pymongo not installed.")
         
         client = MongoClient(self.db_creds['connection_string'])
-        db = client.get_default_database()
+        db = client.get_database()
         
         schemas = {}
         
@@ -104,7 +104,7 @@ class Defog:
         for collection_name in collections:
             collection = db[collection_name]
             rows = collection.find_one()
-            rows = [{"column_name": i, "data_type": str(type(rows[i]))} for i in rows]
+            rows = [{"field_name": i, "data_type": type(rows[i]).__name__} for i in rows]
             schemas[collection_name] = rows
         
         client.close()
@@ -134,7 +134,7 @@ class Defog:
         client = bigquery.Client.from_service_account_json(self.db_creds)
         schemas = {}
         
-        print("Getting schema for each tables in your database...")
+        print("Getting the schema for each table in your database...")
         # get the schema for each table
         for table_name in tables:
             table = client.get_table(table_name)
@@ -144,7 +144,7 @@ class Defog:
         
         client.close()
 
-        print("Sending the schema to the defog servers and generating a Google Sheet. This might take up to 2 minutes...")
+        print("Sending the schema to Defog servers and generating a Google Sheet. This might take up to 2 minutes...")
         # send the schemas dict to the defog servers
         r = requests.post("https://api.defog.ai/get_bigquery_schema_gsheets",
             json={
@@ -269,7 +269,8 @@ class Defog:
                 try:
                     client = MongoClient(self.db_creds["connection_string"])
                     db = client.get_database()
-                    results = eval(f"db.{query['query_generated']}")
+                    results = eval(f"{query['query_generated']}")
+                    results = [i for i in results]
                     return {
                         "columns": results[0].keys(), # assumes that all objects have the same keys
                         "data": results,
